@@ -523,7 +523,7 @@ class ParaDRAM:
                         )
 
         errorOccurred = not isinstance(buildMode,str)
-        if not errorOccurred: errorOccurred = buildMode not in ["release","testing","debug"]
+        if not errorOccurred: errorOccurred = buildMode.split("-")[0] not in ["release","testing","debug"]
         if errorOccurred:
             _pm.abort   ( msg   = "The input argument buildMode must be of type str.\n"
                                 + "It is an optional string argument with default value \"release\"\n."
@@ -614,9 +614,22 @@ class ParaDRAM:
                         , marginBot = 1
                         )
 
-        errorOccurred = not isinstance(buildMode,str)
+        if isinstance(buildMode,str):
+            errorOccurred = False
+            stype = None
+            dummyList = None
+            if "-" in buildMode:
+                dummyList = buildMode.split("-")
+                buildMode = dummyList[0] # build type
+                stype = dummyList[1] # compiler suite
+        else:
+            errorOccurred = True
+
         if not errorOccurred: errorOccurred = buildMode not in ["release","testing","debug"]
+        if not errorOccurred and stype is not None: 
+            errorOccurred = not (stype=="gnu" or stype=="intel")
         if errorOccurred:
+            if dummyList is not None: buildMode = "-".join(dummyList)
             _pm.abort   ( msg   = "The input argument buildMode must be of type str.\n"
                                 + "It is an optional string argument with default value \"release\"\n."
                                 + "possible choices are:\n"
@@ -783,6 +796,9 @@ class ParaDRAM:
         buildModeList.pop(buildModeList.index(buildMode))
         buildModeList.insert(0,buildMode)
         pmcsList = ["intel","gnu"]
+        if stype is not None:
+            pmcsList.pop(pmcsList.index(stype))
+            pmcsList.insert(0,stype)
 
         for buildMode in buildModeList:
 
